@@ -18,6 +18,7 @@ class Api(snappi.Api):
     - username (str): The username for T-Rex Server
     """
     def __init__(self,
+                 host = 'localhost:4501',
                  username='admin',
                  server='localhost',
                  sync_port=4501,
@@ -32,6 +33,14 @@ class Api(snappi.Api):
         - port (str): The rest port of the TestPlatform to connect to.
         - username (str): The username to be used for authentication
         """
+        if host is not None:
+            Validation.validate_host(host)
+            parse_host = host.split(':')
+            if len(parse_host) > 0:
+                server = parse_host[0]
+            if len(parse_host) > 1:
+                sync_port = int(parse_host[1])
+                
         super(Api, self).__init__()
         self._c = STLClient(username=username,
                             server=server,
@@ -42,26 +51,14 @@ class Api(snappi.Api):
                             sync_timeout=sync_timeout,
                             async_timeout=async_timeout
         )
+
         self._port_ids = []
         self._transmit_states = {}
         self._capture = Capture(self._c)
         self._metrics = Metrics(self._c)
         self._link = Link(self._c)
 
-        try:
-            # connect to server
-            self._c.connect()
-        except STLError as e:
-            print(e)
-        
-
-    # try to disconnect when object is deleted
-    def __del__(self):
-        try:
-            self.wait_on_traffic(list(range(len(self._port_ids))))
-            self._c.disconnect()
-        except STLError as e:
-            print(e)
+        Validation.validate_connection(self._c)
 
     
     def wait_on_traffic(self, ports):
@@ -80,7 +77,7 @@ class Api(snappi.Api):
         """Set or update the configuration
         """
         # Create response
-        res = {'warnings': []}
+        res = self.response_warning()
 
         self._config = config
         cfg_obj = json.loads(self._config.serialize())
@@ -91,52 +88,46 @@ class Api(snappi.Api):
             Validation.validate_capture_settings(cfg_obj['captures'], self._port_ids)
             self._capture.set_capture_settings(self._config.captures)
 
-        try:
             self._c.reset(ports = list(range(len(self._port_ids))))
-            # for each Snappi flow, construct the equivalent T-Rex stream
-            for f in cfg_obj["flows"]:
-                # Configure variable manager commands
-                vmCmds = []
+        # for each Snappi flow, construct the equivalent T-Rex stream
+        for f in cfg_obj["flows"]:
+            # Configure variable manager commands
+            vmCmds = []
 
-                # Configure flow rate
-                pps, bps, percent = SetConfig.set_rate(rate=f['rate'])
+            # Configure flow rate
+            pps, bps, percent = SetConfig.set_rate(rate=f['rate'])
 
-                # Configure duration and initialize the transmit mode using rate and duration info
-                mode = SetConfig.set_duration(duration=f['duration'], pps=pps, bps=bps, percent=percent)
+            # Configure duration and initialize the transmit mode using rate and duration info
+            mode = SetConfig.set_duration(duration=f['duration'], pps=pps, bps=bps, percent=percent)
 
-                # Parse config all packet headers. Creates a Scapy packet with provided packet headers
-                headerCmds, pkt_headers, layers = SetConfig.set_packet_headers(f['packet'])
-                vmCmds += headerCmds
-                
-                #Constructs the packet base using all headers
-                pkt_base = None
-                for header in pkt_headers:
-                    pkt_base = header if pkt_base is None else pkt_base/header
+            # Parse config all packet headers. Creates a Scapy packet with provided packet headers
+            headerCmds, pkt_headers, layers = SetConfig.set_packet_headers(f['packet'])
+            vmCmds += headerCmds
+            
+            #Constructs the packet base using all headers
+            pkt_base = None
+            for header in pkt_headers:
+                pkt_base = header if pkt_base is None else pkt_base/header
 
-                # Configure packet size: increment, random, or fixed
-                sizeCmds, pad = SetConfig.set_packet_size(
-                    f_size=f['size'], pkt_base=pkt_base, layers=layers
-                )
-                vmCmds += sizeCmds
-                
-                # TODO: Now fix the checksum of modified packets
-                
+            # Configure packet size: increment, random, or fixed
+            sizeCmds, pad = SetConfig.set_packet_size(
+                f_size=f['size'], pkt_base=pkt_base, layers=layers
+            )
+            vmCmds += sizeCmds
+            
+            # TODO: Now fix the checksum of modified packets
+            
 
-                # Construct the packet with given Flow Variables
-                vm = STLScVmRaw(vmCmds)
-                pkt = STLPktBuilder(pkt = pkt_base/pad, vm = vm)
+            # Construct the packet with given Flow Variables
+            vm = STLScVmRaw(vmCmds)
+            pkt = STLPktBuilder(pkt = pkt_base/pad, vm = vm)
 
-                # Create the stream with given config
-                s1 = STLStream(packet = pkt,
-                            mode = mode)
+            # Create the stream with given config
+            s1 = STLStream(packet = pkt,
+                        mode = mode)
 
-                # Add the stream to the client
-                self._c.add_streams([s1], ports=[self._port_ids.index(f['tx_rx']['port']['tx_name'])])
-
-        except STLError as e:
-            res = {'errors': [e]}
-            self._c.disconnect()
-            print(e)
+            # Add the stream to the client
+            self._c.add_streams([s1], ports=[self._port_ids.index(f['tx_rx']['port']['tx_name'])])
 
         return res
 
@@ -144,6 +135,9 @@ class Api(snappi.Api):
     def set_transmit_state(self, payload):
         """Set the transmit state of flows
         """
+        # Create response
+        res = self.response_warning()
+
         Validation.validate_transmit(payload, self._config)
         ts = json.loads(payload.serialize())
         cfg_obj = json.loads(self._config.serialize())
@@ -163,54 +157,57 @@ class Api(snappi.Api):
                 if p_idx not in ports:
                     ports.append(p_idx)
 
-        try:
-            ports_start = []
-            ports_stop = []
-            ports_resume = []
-            ports_pause = []
-            # Sort each port into start, stop, resume, or pause based on current state
-            for p in ports:
-                if ts['state'] == 'start':
-                    if p not in self._transmit_states or self._transmit_states[p] == 'stop':
-                        ports_start.append(p)
-                    elif self._transmit_states[p] == 'pause':
-                        ports_resume.append(p)
-                elif ts['state'] == 'stop':
-                    ports_stop.append(p)
-                elif ts['state'] == 'pause':
-                    ports_pause.append(p)
+        ports_start = []
+        ports_stop = []
+        ports_resume = []
+        ports_pause = []
+        # Sort each port into start, stop, resume, or pause based on current state
+        for p in ports:
+            if ts['state'] == 'start':
+                if p not in self._transmit_states or self._transmit_states[p] == 'stop':
+                    ports_start.append(p)
+                elif self._transmit_states[p] == 'pause':
+                    ports_resume.append(p)
+            elif ts['state'] == 'stop':
+                ports_stop.append(p)
+            elif ts['state'] == 'pause':
+                ports_pause.append(p)
 
-                self._transmit_states[p] = ts['state']
+            self._transmit_states[p] = ts['state']
 
-            if len(ports_start) > 0:
-                self._c.clear_stats(ports = ports_start)
-                self._c.start(ports = ports_start)
-            if len(ports_stop) > 0:
-                self._c.stop(ports = ports_stop)
-            if len(ports_resume) > 0:
-                self._c.resume(ports = ports_resume)
-            if len(ports_pause) > 0:
-                self._c.pause(ports = ports_pause)
+        if len(ports_start) > 0:
+            self._c.clear_stats(ports = ports_start)
+            self._c.start(ports = ports_start)
+        if len(ports_stop) > 0:
+            self._c.stop(ports = ports_stop)
+        if len(ports_resume) > 0:
+            self._c.resume(ports = ports_resume)
+        if len(ports_pause) > 0:
+            self._c.pause(ports = ports_pause)
 
-        except STLError as e:
-            self._c.disconnect()
-            print(e)
+        return res
 
 
     def set_link_state(self, payload):
+        # Create response
+        res = self.response_warning()
+
         Validation.validate_link(payload, self._port_ids)
         self._link.set_link(payload, self._port_ids)
 
+        return res
+
     
     def set_capture_state(self, payload):
         """Starts capture on all ports that have capture enabled.
         """
-        try:
-            Validation.validate_capture(payload, self._port_ids)
-            self._capture.set_capture(payload, self._port_ids)
-        except STLError as e:
-            self._c.disconnect()
-            print(e)
+        # Create response
+        res = self.response_warning()
+        
+        Validation.validate_capture(payload, self._port_ids)
+        self._capture.set_capture(payload, self._port_ids)
+        
+        return res
         
 
     def get_capture(self, request):
