@@ -1,5 +1,6 @@
 from trex.stl.api import *
 from snappi_trex.util import Util
+from copy import deepcopy
 
 
 class ValueOptions:
@@ -32,6 +33,8 @@ class ValueOptions:
         mask = Util.get_mask(length)
 
         # If length is more than 4 bytes, call get_big_value_cmds
+        if length > 64:
+            return ValueOptions.get_big_big_value_cmds(layer_type, layer_cnt, header_field, length, field_str, fixup)
         if length > 32:
             return ValueOptions.get_big_value_cmds(
                 layer_type, layer_cnt, header_field, length, field_str, fixup
@@ -98,7 +101,7 @@ class ValueOptions:
         """
         Same as get_value_cmds (see above). Handles fields of size 33-64 inclusive
         """
-        varname = "{0}{1}_{2}".format(layer_type, layer_cnt-1, field_str)
+        varname = "{0}{1}_{2}:{3}".format(layer_type, layer_cnt-1, field_str, 8*fixup)
         vm_cmds = []
         mask = Util.get_mask(length) 
 
@@ -162,12 +165,57 @@ class ValueOptions:
                                     is_big=False,
                                     shift = -8*i,
                                     pkt_offset=pkt_offset, 
-                                    offset_fixup=num_bytes-i-1,
+                                    offset_fixup=fixup+num_bytes-i-1,
                                     add_value=add_val_bot))
 
         return vm_cmds
 
 
+    def get_big_big_value_cmds(layer_type, layer_cnt, header_field, length, field_str, fixup):
+        """
+        Handles fields of length greater than 8 bytes
+        """
+        mask = Util.get_mask(64)
+        header_1 = deepcopy(header_field)
+        header_2 = deepcopy(header_field)
+        if 'value' in header_field:
+            header_1['value'] = Util.convert_to_long(header_1['value'], layer_type) >> 64
+            header_2['value'] = Util.convert_to_long(header_2['value'], layer_type) & mask
+        if 'values' in header_field:
+            header_1['values'] = [
+                Util.convert_to_long(v, layer_type) >> 64 for v in header_1['values']
+            ]
+            header_2['values'] = [
+                Util.convert_to_long(v, layer_type) & mask for v in header_2['values']
+            ]
+        if 'increment' in header_field:
+            header_1['value'] = Util.convert_to_long(header_1['increment']['start'], layer_type) >> 64
+            header_1['choice'] = 'value'
+            header_2['increment']['start'] = Util.convert_to_long(header_2['increment']['start'], layer_type) & mask
+            header_2['increment']['step'] = Util.convert_to_long(header_2['increment']['step'], layer_type) & mask
+        if 'decrement' in header_field:
+            header_1['value'] = Util.convert_to_long(header_1['decrement']['start'], layer_type) >> 64
+            header_1['choice'] = 'value'
+            header_2['decrement']['start'] = Util.convert_to_long(header_2['decrement']['start'], layer_type) & mask
+            header_2['decrement']['step'] = Util.convert_to_long(header_2['decrement']['step'], layer_type) & mask
+
+        return ValueOptions.get_big_value_cmds(
+            layer_type=layer_type, 
+            layer_cnt=layer_cnt, 
+            header_field=header_1, 
+            length=length-64, 
+            field_str=field_str, 
+            fixup=fixup
+        ) + ValueOptions.get_big_value_cmds(
+            layer_type=layer_type, 
+            layer_cnt=layer_cnt, 
+            header_field=header_2, 
+            length=64, 
+            field_str=field_str, 
+            fixup=fixup+8
+        )
+
+
 
     def inc_values(start, step, count, length):
         """
